library(dplyr)
library(reshape2)
library(ggplot2)

setwd("~/Desktop/Gaia/Cloud/GoogleTraceData/src/main/R")
source(file.path("Util.R"))

setwd("~/Desktop/Gaia/Cloud/GoogleTraceData/data")
resourcesDir <- "~/Desktop/Gaia/Cloud/GoogleTraceData/src/main/resources"

dataDir="machine_events"
machine_events_headers <- c("time", "machine ID", "event type", "platform ID", 
                            "CPUs", "Memory")
nrows=37780
dataFiles <- listCSVFiles(dataDir)
data <- readDataFiles(dataFiles, machine_events_headers, nrows)
machines <- generateMachineData(data)
machinesTypes <- generateMachineTypes(machines)
machines <- addMachineTypesToMachines(machines, machinesTypes)
writeMachinesTypesFile(machinesTypes) 
writeMachinePowerConsumptionFile(machinesTypes)
writeMachinesFile(machines) 

dataDir="task_events"
task_events_headers <- c("time", "missing info", "job ID", "task index", 
                         "machine ID", "event type", "user", "scheduling class",
                         "priority", "CPU request", "memory request", 
                         "disk space request", "different machines restriction")
nrows=450146
dataFiles <- listCSVFiles(dataDir)
data <- readDataFiles(dataFiles, task_events_headers, nrows)
tasks <- generateTaskData(data)
taskTypes <- generateTaskTypes(tasks)
tasks <- addTaskTypesToTasks(tasks, taskTypes)
writeTaskTypesFile(taskTypes)
writeTasksFile(tasks)

max(data$time)

taskToMachines <- assignTasksToMachines(machines, tasks)
machineTaskCounts <- getMachineTaskCounts(taskToMachines)

dataDir="task_usage"
task_usage_headers <- c("start time", "end time", "job ID", "task index", 
                        "machine ID", "CPU rate", "canonical memory usage",
                        "assigned memory usage", "unmapped page cache",
                        "total page cache", "maximum memory usage", 
                        "disk I/O time", "local disk space usage",
                        "maximum CPU rate", "maximum disk IO time",
                        "cycles per instruction", 
                        "memory accesses per instruction", "sample portion",
                        "aggregation type", "sampled CPU usage")
# One file
nrows=2520773
# Two files
nrows=4873220
# Three files
nrows=7355725
dataFiles <- listCSVFiles(dataDir)
data <- readDataFiles(dataFiles, task_usage_headers, nrows)
taskUsage <- generateTaskUsageData(data)
writeUsageTasksFile(taskUsage, "TaskUsage.csv")

max(taskUsage$time)/(60*60)

# Hour for 250 Tasks
hourTaskUsage <- getTaskUsageForTime(taskUsage, 0, 3600)
# timeEnrtiesPerTask <- hourTaskUsage %>% group_by(Task) %>% tally()
writeUsageTasksFile(hourTaskUsage[hourTaskUsage$Task < 250,],
                    "1hr_250machines_TaskUsage.csv")

# Hout and a half for 1.5K Tasks
hourAndAHalfTaskUsage <- getTaskUsageForTime(taskUsage, 0, 5400)
writeUsageTasksFile(
    hourAndAHalfTaskUsage[hourAndAHalfTaskUsage$Task < 1500,],
    "1.5hrs_1.5K0machines_TaskUsage.csv")

# Three hours for 8K Tasks
threeHoursTaskUsage <- getTaskUsageForTime(taskUsage, 0, 10800)
writeUsageTasksFile(threeHoursTaskUsage[threeHoursTaskUsage$Task < 8000,],
                    "3hrs_8Kmachines_TaskUsage.csv")

# Three hours for 50K Tasks
threeHoursTaskUsage <- getTaskUsageForTime(taskUsage, 0, 10800)
writeUsageTasksFile(threeHoursTaskUsage[threeHoursTaskUsage$Task < 50000,],
                    "3hrs_50Kmachines_TaskUsage.csv")

# Three hours for 100K Tasks
threeHoursTaskUsage <- getTaskUsageForTime(taskUsage, 0, 10800)
writeUsageTasksFile(threeHoursTaskUsage[threeHoursTaskUsage$Task < 100000,],
                    "3hrs_100Kmachines_TaskUsage.csv")

# Used fpr the pretty pictures to get a snapshot of thr DC.
initialTaskUsage <- getInitialTaskUsage(taskUsage)
usagePerMachine <- getUsagePerMachine(tasks, taskToMachines, machines, initialTaskUsage)
